##  Related Resources
  * SAP for Me User, Authorization & Administrator Concept, see [https://support.sap.com/content/s4m/help/access/user-admin-concept.html?anchorId=CloudAdmin![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fsupport.sap.com%2Fcontent%2Fs4m%2Fhelp%2Faccess%2Fuser-admin-concept.html%3FanchorId%3DCloudAdmin "https://support.sap.com/content/s4m/help/access/user-admin-concept.html?anchorId=CloudAdmin")
  * Understanding S-Users & SAP for Me, see [https://learning.sap.com/courses/cloud-onboarding-for-sap-ipd/understanding-s-users-and-sap-for-me-1![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Flearning.sap.com%2Fcourses%2Fcloud-onboarding-for-sap-ipd%2Funderstanding-s-users-and-sap-for-me-1 "https://learning.sap.com/courses/cloud-onboarding-for-sap-ipd/understanding-s-users-and-sap-for-me-1")
  * Access to SAP for Me for LeanIX Customers, see [Access to SAP for Me](https://help.sap.com/docs/leanix/ea/access-to-sap-for-me?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to set up SAP for Me access for your organization.")
  * How to Identify Super/Cloud Administrators, see this community post [https://community.sap.com/t5/crm-and-cx-blog-posts-by-sap/how-to-find-your-super-administrator/ba-p/13515476![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fcommunity.sap.com%2Ft5%2Fcrm-and-cx-blog-posts-by-sap%2Fhow-to-find-your-super-administrator%2Fba-p%2F13515476 "https://community.sap.com/t5/crm-and-cx-blog-posts-by-sap/how-to-find-your-super-administrator/ba-p/13515476")


YesNo
Send
